/**
 * Třída Video představuje jedno video (jeden pořad/nahrávku). Informace o videu je možné
 * ukládat a získávat. K nahrávce lze nastavit komentář a zda vlastníme kopii videa.
 * 
 * @author Michael Kolling and David J. Barnes
 * @author Luboš Pavlíček
 * @version  září 2005
 */
public class Video 
{
    private String titul;
    private String reziser;
    private int    delka;
    private boolean vlastnim;
    private String komentar;

    /**
     * Konstruktor pro vytvoření instance třídy Video. Vlastnictví nahrávky je potřeba
     * nastavit samostatně pomocí metody setOwn
     * 
     * @param   titul   titul videokazety/nahrávky
     * @param   reziser režisér nahrávky
     * @param   delka     délka nahrávky v minutách
     */
    public Video(String titul, String reziser, int delka)
    {
        this.titul = titul;
        this.reziser = reziser;
        this.delka = delka;
        vlastnim = false;
        komentar = "<bez komentáře>";
    }

    /**
     * Vlož komentář k nahrávce.
     * @param   komentar   komentář k nahrávce
     */
    public void setKomentar(String komentar)
    {
        this.komentar = komentar;
    }

    /**
     * Vrací komentář k této nahrávce.
     * 
     * @return       komentář k nahrávce
     */
    public String getKomentar()
    {
        return komentar;
    }

    /**
     * nastavení příznaku, zda vlastníme kopii tohoto videa.
     * 
     * @param   vlastnim    true, pokud vlastním nahrávku tohoto videa
     */
    public void setVlastnim(boolean vlastnim)
    {
        this.vlastnim = vlastnim;
    }

    /**
     * vrací informaci, zda vlastníme kopii tohoto videa.
     * 
     * @return      true, pokud vlastníme kopii tohoto videa
     */
    public boolean getVlastnim()
    {
        return vlastnim;
    }

    /**
     * Vypíše informace o videu do textového okna.
     */
    public void print()
    {
        System.out.print("video: " + titul + " (" + delka + " min)");
        if(vlastnim) {
            System.out.println("*");
        } else {
            System.out.println();
        }
        System.out.println("    " + reziser);
        System.out.println("    " + komentar);
    }
}
